SystemOrganization addCategory: #'SUnit-Kernel'!
SystemOrganization addCategory: #'SUnit-Extensions'!
SystemOrganization addCategory: #'SUnit-Tests'!
SystemOrganization addCategory: #SUnit!

Exception subclass: #TestFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestFailure commentStamp: '<historical>' prior: 0!
Signaled in case of a failed test (failure). The test framework distinguishes between failures and errors. A failure is anticipated and checked for with assertions. Errors are unanticipated problems like a division by 0 or an index out of bounds ...!

TestFailure subclass: #ResumableTestFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!ResumableTestFailure commentStamp: '<historical>' prior: 0!
A ResumableTestFailure triggers a TestFailure, but lets execution of the TestCase continue. this is useful when iterating through collections, and #assert: ing on each element. in combination with methods like testcase>>#assert:description:, this lets you run through a whole collection and note which tests pass.

here''s an example:

	

	(1 to: 30) do: [ :each |
		self assert: each odd description: each printString, ' is even' resumable: true]

for each element where #odd returns <false>, the element will be printed to the Transcript. !

!ResumableTestFailure methodsFor: 'camp smalltalk' stamp: ''!
isResumable
	"Of course a ResumableTestFailure is resumable ;-)"

	^true! !

!ResumableTestFailure methodsFor: 'camp smalltalk' stamp: ''!
sunitExitWith: aValue
	self resume: aValue! !

!TestFailure methodsFor: 'camp smalltalk' stamp: 'ajh 1/24/2003 19:23'!
defaultAction

	Processor activeProcess
		debug: self signalerContext
		title: self description! !

!TestFailure methodsFor: 'camp smalltalk' stamp: 'ajh 2/1/2003 00:58'!
isResumable
	
	^ false! !

Object subclass: #TestCase
	instanceVariableNames: 'testSelector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestCase commentStamp: 'kph 12/16/2006 08:00' prior: 0!
A TestCase is a Command representing the future running of a test case. Create one with the class method #selector: aSymbol, passing the name of the method to be run when the test case runs.

When you discover a new fixture, subclass TestCase, declare instance variables for the objects in the fixture, override #setUp to initialize the variables, and possibly override# tearDown to deallocate any external resources allocated in #setUp.

When you are writing a test case method, send #assert: aBoolean when you want to check for an expected value. For example, you might say "self assert: socket isOpen" to test whether or not a socket is open at a point in a test.

Modification Notes: KPH 16/12/06
======================================
Removed the magic that a TestCase subclass with no test selectors automatically inherits testSelectors. This can and should be explicitly set by overriding #shouldInheritSelectors to true so as to make the behaviour explicit.

simplification/refactoring/enhancement:

    All hard wired references to 'test*' have been removed from the suiteBuild protocol, indeed the suiteBuild protocol has been greatly simplified/removed.

More flexible suite building API:

Asking an abstract class for #suite: will build the entire suite for all of its concrete subclasses.
Asking a concrete class for #suite: will just return the suite for that one class.

Suites are defined as class methods for a testcase class.
example:
	myTestSuite
		"all 'test*' methods, but not those in category 'long tests', or tests flagged with #BrokenTest" 
		^ #( 'include:test*' 'exclude@long tests' 'exclude#BrokenTest' )
 
Suites are obtained via either 
	a) a selector which references a defined suite or 
	b) an explicit string
	c) an array of a & b.

	TestCase suite: #myTestSuite.		
	TestCase suite: 'include:test*'.
	TestCase suite: #( 'include:test*' 'include:longtest*').

The array can be used to combine other suites
example:
	myTestSuiteWithLongTests
		^ #( #myTestSuite 'include@long tests' ) 

Published Suites API

#publishedSuites provides a list of test suites published by each TestCase class that can be picked in the TestRunner. This provides a natural UI for selecting from a range of testing scenarios. e.g. tests for different products, releases, platforms, performance monitoring tests, long tests, tests needing additional services (db)

Published Filters API

#published filters provides a list of filters that can be picked in the TestRunner. This provides a natural UI for including/excluding groups of tests from a suite.
   
publishedFilters
	^#( #filterOutBrokenTests )

filterOutBrokenTests
	^ 'exclude#BrokenTest'

With this new publishing suites API the functionality of LongTestCase is no longer needed. It could be removed but is left for backwards compatibility.

Additional asserts

added #assert:equals and #assert:includes  

 !

TestCase subclass: #ClassClonerTestResourceTest
	instanceVariableNames: 'originalClass clonedClass'
	classVariableNames: 'ClassVar'
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!ClassClonerTestResourceTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 20:32'!
changeClassVar

ClassVar := 'changed'.! !

!ClassClonerTestResourceTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 20:32'!
classVar

^ ClassVar! !

!ClassClonerTestResourceTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 20:32'!
initialize

 ClassVar := 'initialized'.! !

!ClassClonerTestResourceTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/2/2006 05:11'!
resources

^ Set with: ClassClonerTestResource! !

!ClassClonerTestResourceTest methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 20:33'!
setUp

originalClass := self class initialize.
clonedClass := ClassClonerTestResource current cloneOf: originalClass.
clonedClass initialize.! !

!ClassClonerTestResourceTest methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 20:05'!
testChangeClone

clonedClass changeClassVar.

self assert: (clonedClass classVar = 'changed').
self assert: (originalClass classVar = 'initialized')! !

!ClassClonerTestResourceTest methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 20:04'!
testInitialState

self assert: (clonedClass classVar = 'initialized').
self assert: (originalClass classVar = 'initialized').
self deny: (clonedClass classVar == originalClass classVar). 
self deny: ((clonedClass classPool at: #ClassVar) == (originalClass classPool at: #ClassVar)). ! !

TestCase subclass: #LongTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!LongTestCase commentStamp: 'kph 12/14/2006 03:43' prior: 0!
The ability to define categories of tests such as LongTestCase has been rolled into TestCase.
This class is present for compatibility only, but is now obsolete.
!

!LongTestCase methodsFor: 'as yet unclassified' stamp: 'kph 12/16/2006 06:45'!
filterOnlyLongTests

"all our tests are long"

	^  #(  )! !

!LongTestCase methodsFor: 'as yet unclassified' stamp: 'kph 12/16/2006 06:45'!
filterSkipLongTests

"all our tests are long"
	^  #( 'exclude:*' )! !

TestCase subclass: #ResumableTestFailureTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
errorTest
	1 zork
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: 'md 2/22/2006 14:17'!
failureLog
	^Transcript
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
failureTest
	self
		assert: false description: 'You should see me' resumable: true; 
		assert: false description: 'You should see me too' resumable: true; 
		assert: false description: 'You should see me last' resumable: false; 
		assert: false description: 'You should not see me' resumable: true
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
isLogging
	^false
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
okTest
	self assert: true
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
regularTestFailureTest
	self assert: false description: 'You should see me'
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
resumableTestFailureTest
	self
		assert: false description: 'You should see me' resumable: true; 
		assert: false description: 'You should see me too' resumable: true; 
		assert: false description: 'You should see me last' resumable: false; 
		assert: false description: 'You should not see me' resumable: true
			! !

!ResumableTestFailureTestCase methodsFor: 'Not categorized' stamp: ''!
testResumable
	| result suite |
	suite := TestSuite new.
	suite addTest: (self class selector: #errorTest).
	suite addTest: (self class selector: #regularTestFailureTest).
	suite addTest: (self class selector: #resumableTestFailureTest).
	suite addTest: (self class selector: #okTest).
	result := suite run.
	self assert: result failures size = 2;
		assert: result errors size = 1
			! !

TestCase subclass: #SUnitExtensionsTest
	instanceVariableNames: 'stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
assertionFailedInRaiseWithExceptionDoTest

	self 
		should: [ Error signal ]
		raise: Error
		withExceptionDo: [ :anException | self assert: false ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
differentExceptionInShouldRaiseWithExceptionDoTest

	[ self 
		should: [ Error signal ]
		raise: Halt
		withExceptionDo: [ :anException | self assert: false description: 'should:raise:withExceptionDo: handled an exception that should not handle'] ]
	on: Error
	do: [ :anException | anException return: nil ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
errorInRaiseWithExceptionDoTest

	self 
		should: [ Error  signal ]
		raise: Error
		withExceptionDo: [ :anException | Error signal: 'A forced error' ]! !

!SUnitExtensionsTest methodsFor: 'test support' stamp: ''!
failureLog
	^self stream! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'md 8/2/2006 11:04'!
invalidShouldNotTakeMoreThan

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThan: 50 milliSeconds.! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: ''!
invalidShouldNotTakeMoreThanMilliseconds

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThanMilliseconds: 50! !

!SUnitExtensionsTest methodsFor: 'testing' stamp: ''!
isLogging
	^true! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
noExceptionInShouldRaiseWithExceptionDoTest

	self 
		should: [  ]
		raise: Error
		withExceptionDo: [ :anException | Error signal: 'Should not get here' ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: ''!
shouldFixTest

	self shouldFix: [ Error signal: 'any kind of error' ]
! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
shouldRaiseWithExceptionDoTest

	self 
		should: [ Error signal: '1' ]
		raise: Error
		withExceptionDo: [ :anException | self assert: anException messageText = '1' ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
shouldRaiseWithSignalDoTest

	self 
		should: [ Error signal: '1' ]
		raise: Error
		withExceptionDo: [ :anException | self assert: anException messageText = '1' ]! !

!SUnitExtensionsTest methodsFor: 'accessing' stamp: ''!
stream
	stream isNil ifTrue: [stream := WriteStream on: String new].
	^stream! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:39'!
testAssertionFailedInRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #assertionFailedInRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult failures includes: testCase).
	self assert: testResult failures size=1.
	self assert: testResult passed isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 21:15'!
testAutoAssertFalse
	| booleanCondition |
	self assert: self isLogging.
	self should: [ self assert: 1 = 2 description: 'self assert: 1 = 2' ] raise: TestResult failure.
	booleanCondition := (self stream contents subStrings: {Character cr}) last = 'self assert: 1 = 2'.
	self assert: booleanCondition! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testAutoAssertTrue
	self assert: 1 = 1.
	self assert: true! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 21:16'!
testAutoDenyFalse
	| booleanCondition |
	self assert: self isLogging.
	self should: [ self deny: 1 = 1 description: 'self deny: 1 = 1'.] raise: TestResult failure.
	booleanCondition := (self stream contents subStrings:  {Character cr}) last = 'self deny: 1 = 1'.
	self assert: booleanCondition! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testAutoDenyTrue
	self deny: 1 = 2.
	self deny: false! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testDifferentExceptionInShouldRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #differentExceptionInShouldRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult passed includes: testCase).
	self assert: testResult errors isEmpty.
	self assert: testResult failures isEmpty.
	self assert: testResult passed size=1! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testErrorInRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #errorInRaiseWithExceptionDoTest.
	testResult := testCase run.
		
	self assert: (testResult errors includes: testCase).
	self assert: testResult errors size=1.
	self assert: testResult failures isEmpty.
	self assert: testResult passed isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'tests' stamp: 'md 4/2/2006 14:02'!
testExceptionWithMatchingString
	self should: [ Object obsolete ] raise: Error whoseDescriptionIncludes: 'NOT obsolete' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'tests' stamp: 'md 4/2/2006 14:02'!
testExceptionWithoutMatchingString
	self should: [ Object obsolete ] raise: Error whoseDescriptionDoesNotInclude: 'Zero' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'md 8/2/2006 11:06'!
testInvalidShouldNotTakeMoreThan

	| testCase testResult |

	testCase := self class selector: #invalidShouldNotTakeMoreThan.
	testResult := testCase run.

	self assert: testResult passed isEmpty.
	self assert: testResult failures size = 1.
	self assert: (testResult failures includes: testCase).
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testInvalidShouldNotTakeMoreThanMilliseconds

	| testCase testResult |

	testCase := self class selector: #invalidShouldNotTakeMoreThanMilliseconds.
	testResult := testCase run.

	self assert: testResult passed isEmpty.
	self assert: testResult failures size = 1.
	self assert: (testResult failures includes: testCase).
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testNoExceptionInShouldRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #noExceptionInShouldRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult failures includes: testCase).
	self assert: testResult failures size=1.
	self assert: testResult passed isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'tests' stamp: 'md 4/2/2006 14:02'!
testNoExceptionWithMatchingString
	self shouldnt: [ Object obsolete ] raise: Error whoseDescriptionIncludes: 'Zero' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'tests' stamp: 'md 4/2/2006 14:02'!
testNoExceptionWithNoMatchingString
	self shouldnt: [ Object obsolete ] raise: Error whoseDescriptionDoesNotInclude: 'NOT' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testShouldFix

	| testCase testResult  |
	
	testCase := self class selector: #shouldFixTest.
	testResult := testCase run.
	
	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size=1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testShouldRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #shouldRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size=1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'md 8/2/2006 11:06'!
testValidShouldNotTakeMoreThan
	| testCase testResult |

	testCase := self class selector: #validShouldNotTakeMoreThan.
	testResult := testCase run.

	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size = 1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testValidShouldNotTakeMoreThanMilliseconds

	| testCase testResult |

	testCase := self class selector: #validShouldNotTakeMoreThanMilliseconds.
	testResult := testCase run.

	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size = 1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'md 8/2/2006 11:05'!
validShouldNotTakeMoreThan

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThan:  200 milliSeconds.! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: ''!
validShouldNotTakeMoreThanMilliseconds

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThanMilliseconds: 200! !

TestCase subclass: #SUnitTest
	instanceVariableNames: 'hasRun hasSetup hasRanOnce'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SUnitTest commentStamp: '<historical>' prior: 0!
This is both an example of writing tests and a self test for the SUnit. The tests 
here are pretty strange, since you want to make sure things blow up. You should 
not generally have to write tests this complicated in structure, although they 
will be far more complicated in terms of your own objects- more assertions, more 
complicated setup. Kent says: "Never forget, however, that if the tests are hard 
to write, something is probably wrong with the design".!

!SUnitTest methodsFor: 'private' stamp: ''!
assertForTestResult: aResult runCount: aRunCount passed: aPassedCount failed: aFailureCount errors: anErrorCount

	self
		assert: aResult runCount = aRunCount;
		assert: aResult passedCount = aPassedCount;
		assert: aResult failureCount = aFailureCount;
		assert: aResult errorCount = anErrorCount
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
error
	3 zork
			! !

!SUnitTest methodsFor: 'testing' stamp: 'md 2/22/2006 14:17'!
errorShouldntRaise
	self 
		shouldnt: [self someMessageThatIsntUnderstood] 
		raise: Notification new
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
fail
	self assert: false
			! !

!SUnitTest methodsFor: 'accessing' stamp: ''!
hasRun
	^hasRun
			! !

!SUnitTest methodsFor: 'accessing' stamp: ''!
hasSetup
	^hasSetup
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
noop
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
setRun
	hasRun := true
			! !

!SUnitTest methodsFor: 'running' stamp: ''!
setUp
	hasSetup := true
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testAssert
	self assert: true.
	self deny: false
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testDefects
	| result suite error failure |
	suite := TestSuite new.
	suite addTest: (error := self class selector: #error).
	suite addTest: (failure := self class selector: #fail).
	result := suite run.
	self assert: result defects asArray = (Array with: error with: failure).
	self
		assertForTestResult: result
		runCount: 2
		passed: 0
		failed: 1
		errors: 1
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testDialectLocalizedException

	self
		should: [TestResult signalFailureWith: 'Foo']
		raise: TestResult failure.
	self
		should: [TestResult signalErrorWith: 'Foo']
		raise: TestResult error.

			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testError

	| case result |

	case := self class selector: #error.
	result := case run.
	self
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 0
		errors: 1.

	case := self class selector: #errorShouldntRaise.
	result := case run.
	self 
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 0
		errors: 1
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testException

	self
		should: [self error: 'foo']
		raise: TestResult error
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testFail

	| case result |

	case := self class selector: #fail.
	result := case run.

	self
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 1
		errors: 0
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testIsNotRerunOnDebug

	| case |

	case := self class selector: #testRanOnlyOnce.
	case run.
	case debug
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testRan

	| case |

	case := self class selector: #setRun.
	case run.
	self assert: case hasSetup.
	self assert: case hasRun
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testRanOnlyOnce

	self assert: hasRanOnce ~= true.
	hasRanOnce := true
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testResult

	| case result |

	case := self class selector: #noop.
	result := case run.

	self
		assertForTestResult: result
		runCount: 1
		passed: 1
		failed: 0
		errors: 0
			! !

!SUnitTest methodsFor: 'testing(long)' stamp: 'md 2/22/2006 14:16'!
testRunning

	(Delay forSeconds: 2) wait
			! !

!SUnitTest methodsFor: 'testing' stamp: 'kph 12/18/2006 01:58'!
testSelectorsMatchingCategory
	| selectors |
	selectors := self class in: self class selectorsMatchingCategory: 'acc*'.
	self assert: selectors includes: #hasRun.
	self assert: selectors includes: #hasSetup.
	self assert: selectors size = 2.
	! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testShould

	self
		should: [true];
		shouldnt: [false]
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testSuite

	| suite result |

	suite := TestSuite new.
	suite 
		addTest: (self class selector: #noop);
		addTest: (self class selector: #fail);
		addTest: (self class selector: #error).

	result := suite run.

	self
		assertForTestResult: result
		runCount: 3
		passed: 1
		failed: 1
		errors: 1
			! !

!SUnitTest methodsFor: 'testing' stamp: 'DF 3/17/2006 01:30'!
testWithExceptionDo

	self
		should: [self error: 'foo']
		raise: TestResult error
		withExceptionDo: [:exception |
			self assert: (exception description includesSubString: 'foo')
		]
			! !

TestCase subclass: #SimpleTestResourceTestCase
	instanceVariableNames: 'resource'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SimpleTestResourceTestCase class methodsFor: 'Not categorized' stamp: ''!
resources
	^Set new add: SimpleTestResource; yourself
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
dummy
	self assert: true
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
error
	'foo' odd
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
fail
	self assert: false
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
setRun
	resource setRun
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
setUp
	resource := SimpleTestResource current
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
testRan
	| case |

	case := self class selector: #setRun.
	case run.
	self assert: resource hasSetup.
	self assert: resource hasRun
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
testResourceInitRelease
	| result suite error failure |
	suite := TestSuite new.
	suite addTest: (error := self class selector: #error).
	suite addTest: (failure := self class selector: #fail).
	suite addTest: (self class selector: #dummy).
	result := suite run.
	self assert: resource hasSetup
			! !

!SimpleTestResourceTestCase methodsFor: 'Not categorized' stamp: ''!
testResourcesCollection
	| collection |
	collection := self resources.
	self assert: collection size = 1
			! !

TestCase subclass: #SuiteBuildingTest
	instanceVariableNames: 'suite filtered selectors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SuiteBuildingTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/18/2006 16:41'!
allFood

^ #( #fruitSuiteDefn #vegMethodsDefn )! !

!SuiteBuildingTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/18/2006 08:16'!
fruitSuiteDefn

^ 'include:fruit*'! !

!SuiteBuildingTest class methodsFor: 'as yet unclassified' stamp: 'kph 12/18/2006 08:16'!
vegMethodsDefn

^ 'include:veg*'! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:53'!
canGetAllFlaggedMethods
	
	suite := self class suite: 'include#flag:'.
	 
 	self assert: (suite tests size = 6).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:45'!
checkSuiteHasUniqueTestsOnly

	suite := TestSuite new.
	suite 
		addTest: (self class selector: #noop);
		addTest: (self class selector: #noop);
		addTest: (self class selector: #noop).

	self assert: (suite tests size = 1).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:51'!
excludeCategory

	suite := self class suite: #( 'include:*' 'exclude@*tests*' ).
	 
 	self assert: (suite tests size = 5).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:19'!
excludeFlag

	suite := self class suite: #( 'include@food' 'exclude#Veg' ).
	 
 	self assert: (suite tests size = 3).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:50'!
excludeSelectors

	suite := self class suite: #( 'include@food' 'exclude:fruit*' ).
	 
 	self assert: (suite tests size = 2).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/19/2006 05:25'!
filterReject

	filtered := TestSuite classes: (Array with: self class) suites: #(#allFood) filters: #(#fruitSuiteDefn) select: false.
	
 	self assert: (filtered tests size = 2).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/19/2006 05:25'!
filterSelect
	 
	filtered := TestSuite classes: (Array with: self class) suites: #(#allFood) filters: #(#fruitSuiteDefn) select: true.
	
 	self assert: (filtered tests size = 3).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:42'!
flaggedWithALoneSymbol

	#LoneSymbol.

	selectors := self class in: self class selectorsFlagged: #LoneSymbol.
	self assert: selectors includes: #flaggedWithALoneSymbol.
	self assert: selectors size = 1.
! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:43'!
flaggedWithFlag

	self flag: #Flagged.
	
	selectors := self class in: self class selectorsFlagged: #Flagged.
	self assert: selectors includes: #flaggedWithFlag.
	self assert: selectors size = 1.
 ! !

!SuiteBuildingTest methodsFor: 'food' stamp: 'kph 12/19/2006 04:54'!
fruitApple

self flag: #BugFix.
self flag: #Fruit! !

!SuiteBuildingTest methodsFor: 'food' stamp: 'kph 12/18/2006 08:15'!
fruitBanana

self flag: #Fruit! !

!SuiteBuildingTest methodsFor: 'food' stamp: 'kph 12/18/2006 08:15'!
fruitPear

self flag: #Fruit! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/19/2006 01:26'!
removeTestsFromSuite

	suite := TestSuite new.
	suite 
		addTest: (self class selector: #noop);
		removeAllFoundIn: (Array with:(self class selector: #noop)).

	self assert: (suite tests size = 0).! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:44'!
selectorsMatching
	 
	selectors := self class in: self class selectorsMatching: 'veg*'.
	self assert: selectors includes: #vegPotatoe.
	self assert: selectors includes: #vegCarrot.
	self assert: selectors size = 2.
	! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:47'!
selectorsMatchingCategory
	 
	selectors := self class in: self class selectorsMatchingCategory: 'food'.
	self assert: selectors size = 5.
	! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:47'!
selectorsMatchingCategoryWild
	 
	selectors := self class in: self class selectorsMatchingCategory: '*oo*'.
	self assert: selectors size = 5.
	! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:24'!
suiteFromArray

	suite := self class suite: #( #fruitSuiteDefn 'include:veg*' ).
	 
 	self assert: (suite tests size = 5).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:48'!
suiteFromCategory

	suite := self class suite: 'include@food'.
	 
 	self assert: (suite tests size = 5).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:18'!
suiteFromIncludeFlag
 
	suite := self class suite: 'include#Fruit'.
	 
 	self assert: (suite tests size = 3).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:25'!
suiteFromSelector

	suite := self class suite: #fruitSuiteDefn.
	 
 	self assert: (suite tests size = 3).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 16:41'!
suiteFromSelectorWithArray

	suite := self class suite: #allFood.
	 
 	self assert: (suite tests size = 5).
	 ! !

!SuiteBuildingTest methodsFor: 'standard tests' stamp: 'kph 12/18/2006 08:29'!
suiteFromString

	suite := self class suite: 'include:fruit*'.
	 
 	self assert: (suite tests size = 3).
	 ! !

!SuiteBuildingTest methodsFor: 'food' stamp: 'kph 12/18/2006 08:16'!
vegCarrot

self flag: #Veg! !

!SuiteBuildingTest methodsFor: 'food' stamp: 'kph 12/18/2006 08:16'!
vegPotatoe

self flag: #Veg! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/21/2006 05:12'!
allStandardTests

"Tests the standard release of this system."

	^ #( 'include:test*' 'include@standard tests*')! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/19/2006 04:53'!
bugFixes

"Tests specifically marked as bug fixes"

	^ #( 'include:bug*' 'include@bug fixes' 'include#BugFix' )! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
debug: aSymbol

	^(self selector: aSymbol) debug
			! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 10/26/2006 11:53'!
emptySuite
	^ TestSuite new! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/21/2006 04:50'!
expectedFailures

"Tests explicitly flagged as expected failures"

	^  #( 'include@*(expected)*' 'include#ExpectToFail' )! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 12/19/2006 06:57'!
in: aClass selectorsFlagged: literal  

	"Answer a set of selectors whose methods access the argument as a literal.
	 this finds self flag: #literal, or #literal. in a method."

	| action theLiteral method |
	
	theLiteral := literal.
	action := (literal first = $^) ifFalse: [ #select: ] ifTrue: [ theLiteral := (literal copyWithoutFirst) asSymbol. #reject:  ]. 

	^ (self selectorsUnaryIn: aClass) perform: action with: [ :selector | 
		 method :=  aClass lookupSelector: selector.
		 method ifNil:[ false ] ifNotNil: [ method hasLiteral: theLiteral ] 
	].! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 12/19/2006 06:57'!
in: aClass selectorsMatching: match 
 	
	| action theMatch |
	
	theMatch := match.
	action := match first = $^ ifFalse: [ #select: ] ifTrue: [ theMatch := match copyWithoutFirst. #reject:  ]. 

	^(self selectorsUnaryIn: aClass) perform: action with: [:selector | theMatch match: selector ]
			 ! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 12/19/2006 06:57'!
in: aClass selectorsMatchingCategory: match 
 	
	| action theMatch |
	
	theMatch := match.
	action := match first = $^ ifFalse: [ #select: ] ifTrue: [ theMatch := match copyWithoutFirst. #reject:  ]. 
	
	^ (self selectorsUnaryIn: aClass)
			perform: action with: [:selector | 
				 theMatch match: (aClass organization categoryOfElement: selector) asString ]
			 ! !

!TestCase class methodsFor: 'testing' stamp: 'md 2/22/2006 14:21'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #TestCase
			! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/18/2006 06:25'!
longTests

"Any tests that may take a long time"

	^  #( 'include@*(long)*' 'include#LongTest' )! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/21/2006 08:16'!
publishedFilters
	^ #(#longTests #expectedFailures #bugFixes #toDo #usesNetwork) ! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/18/2006 06:30'!
publishedSuites
	^ #(#allStandardTests)! !

!TestCase class methodsFor: 'accessing' stamp: ''!
resources

	^#()
			! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
run: aSymbol

	^(self selector: aSymbol) run
			! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
selector: aSymbol

	^self new setTestSelector: aSymbol
			! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 1/9/2007 06:00'!
selectorsUnaryIn: aClass
 	
	^ (((aClass askFor: #shouldInheritSelectors) ifNil: [ false ])
		ifTrue: [aClass allSelectors]
		ifFalse: [aClass selectors]) 
		
		reject: [ :selector | selector last = $: ]
			  ! !

!TestCase class methodsFor: 'testing' stamp: 'kph 11/2/2006 02:14'!
shouldInheritSelectors
	"I should inherit from an Abstract superclass but not from a concrete
	one by default, If a test case with selectors wants to inherit selectors 
	from a concrete superclass, override this to true in that subclass."
	^ self superclass isAbstract
		and: [self superclass name ~= #TestCase]! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 12/19/2006 00:45'!
suite
	^ self suite: #allStandardTests! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 12/19/2006 05:28'!
suite: spec
	^ self suite: spec onTo: self emptySuite! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 12/19/2006 05:32'!
suite: spec filter: filter select: selectOrRemove

	^ self emptySuite classes: (Array with: self) suites: spec filters: filter select: selectOrRemove! !

!TestCase class methodsFor: 'building suites' stamp: 'kph 1/9/2007 06:21'!
suite: spec onTo: suite 

	"spec specifies a test suite as either:
	
		a) a selector (symbol) to be performed if possible to obtain either b or c.
		b) an array of items over which to iterate.
		c) a spec string consisting of include/exclude,  :/@/#, and a match string
		
		: - apply match to method selectors
		@ - apply match method category
		# - method with flag: #match"
		
	|  classes selectors action theSpec theMatch theType |
	
	theSpec := spec isSymbol 
		ifTrue: [ self askFor: spec ifAbsent: [ ^suite ] ] 
		ifFalse: [ spec ].
		
	theSpec isArray
		ifTrue: [ 
			theSpec do: [ :eachSpec | self suite: eachSpec onTo: suite ].
			^suite ].

	action := #addTests:.
		
	classes := self isAbstract ifTrue: [ self allSubclasses reject: [:c | c isAbstract] ] 
							ifFalse: [ Array with: self ].
	
	theMatch := theSpec allButFirst: 8.
	theType := theSpec at: 8 ifAbsent: [ self error: 'invalid test suite spec' ].
	
	(theSpec beginsWith: 'include') ifTrue: [ action := #addTests: ].
	(theSpec beginsWith: 'exclude') ifTrue: [ action := #removeAllFoundIn: ].
	
	selectors := Set new.
	
	classes do: [ :testClass |
		selectors :=
			(theType caseOf: 
				{	[ $: ]  -> [ self in: testClass selectorsMatching: theMatch ].
					[ $# ] -> [ self in: testClass selectorsFlagged: theMatch asSymbol ].
				  	[ $@ ] -> [ self in: testClass selectorsMatchingCategory: theMatch ]. } ).

		suite perform: action 
			  with: (selectors collect: [:each | testClass selector: each ]). 
	].

	
	^ suite
 ! !

!TestCase class methodsFor: 'accessing' stamp: 'kph 10/26/2006 05:56'!
sunitVersion
	^ '3.2b'! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/21/2006 04:43'!
toDo

"Tests specifically marked as bug fixes"

	^ #( 'include:todo*' 'include@*(todo)*' 'include#ToDo' )! !

!TestCase class methodsFor: 'published suites' stamp: 'kph 12/21/2006 08:15'!
usesNetwork

"Any tests that are marked as using the network"

	^  #( 'include@*(net)*' 'include#UsesNetwork' )! !

!TestCase methodsFor: 'equality' stamp: 'kph 12/16/2006 10:44'!
<= aTestCase

^(self printString <= aTestCase printString)! !

!TestCase methodsFor: 'equality' stamp: 'kph 12/16/2006 07:32'!
= aTestCase

^(aTestCase class == self class) and: [ aTestCase selector == self selector ]

	! !

!TestCase methodsFor: 'categorization utilities' stamp: 'kph 12/21/2006 05:06'!
addCategoryMark: aWord

	"adds a (tag) to the category of this test method, e.g. 'tests (long)' "

	self class methodDict at: self selector ifAbsent: [ ^ self ].

	^self class organization classify: self selector under: (self category,'(', aWord,')'); removeEmptyCategories.! !

!TestCase methodsFor: 'dependencies' stamp: ''!
addDependentToHierachy: anObject 
	"an empty method. for Composite compability with TestSuite"


			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 10:59'!
assert: aBooleanOrBlock

	aBooleanOrBlock value ifFalse: [self signalFailure: 'Assertion failed']
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
assert: aBooleanOrBlock description: aString
	aBooleanOrBlock value ifFalse: [
		self logFailure: aString.
		TestResult failure signal: aString]
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
assert: aBooleanOrBlock description: aString resumable: resumableBoolean 
	| exception |
	aBooleanOrBlock value
		ifFalse: 
			[self logFailure: aString.
			exception := resumableBoolean
						ifTrue: [TestResult resumableFailure]
						ifFalse: [TestResult failure].
			exception signal: aString]
			! !

!TestCase methodsFor: 'accessing' stamp: 'kph 11/2/2006 01:30'!
assert: a equals: b 
	^ self assert: (a = b)
! !

!TestCase methodsFor: 'accessing' stamp: 'kph 11/2/2006 01:29'!
assert: a includes: b 
	^ self assert: (a includes: b)
! !

!TestCase methodsFor: 'categorization utilities' stamp: 'kph 12/18/2006 10:42'!
category

^ (self class organization categoryOfElement: self selector) ifNil: [ '' ]

	! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
debug
	self resources do: [:res | 
		res isAvailable ifFalse: [^res signalInitializationError]].
	[(self class selector: testSelector) runCase] 
		ensure: [self resources do: [:each | each reset]]
			! !

!TestCase methodsFor: 'running' stamp: 'bp 11/15/2004 18:13'!
debugAsFailure
	| semaphore |
	semaphore := Semaphore new.
	self resources do: [:res | 
		res isAvailable ifFalse: [^res signalInitializationError]].
	[semaphore wait. self resources do: [:each | each reset]] fork.
	(self class selector: testSelector) runCaseAsFailure: semaphore.! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
deny: aBooleanOrBlock

	self assert: aBooleanOrBlock value not
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
deny: aBooleanOrBlock description: aString
	self assert: aBooleanOrBlock value not description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
deny: aBooleanOrBlock description: aString resumable: resumableBoolean 
	self
		assert: aBooleanOrBlock value not
		description: aString
		resumable: resumableBoolean
			! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:27'!
executeShould: aBlock inScopeOf: anExceptionalEvent 
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: true]
			! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:27'!
executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: aString
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: (ex description includesSubString: aString) ]
			! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:27'!
executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: aString
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: (ex description includesSubString: aString) not ]
			! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/20/2006 23:32'!
executeShould: aBlock inScopeOf: anException withExceptionDo: anotherBlock

	^[aBlock value.
 	false] 
		on: anException
		do: [:exception | 
			anotherBlock value: exception.
			exception return: true]! !

!TestCase methodsFor: 'testing' stamp: 'JF 7/30/2003 13:40'!
expectedFailures
	^ Array new! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/13/2006 23:21'!
fail

	^self assert: false! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:17'!
failureLog	
	^Transcript

			! !

!TestCase methodsFor: 'equality' stamp: 'kph 12/16/2006 05:18'!
hash

^ self printString hash! !

!TestCase methodsFor: 'categorization utilities' stamp: 'kph 12/18/2006 10:43'!
isCategoryMarkedWith: aWord

	"tests to the presence of a (tag) in the category of this test method, e.g. 'tests (long)' "

	^self category includesSubString: '(', aWord, ')'.! !

!TestCase methodsFor: 'running' stamp: ''!
isLogging
	"By default, we're not logging failures. If you override this in 
	a subclass, make sure that you override #failureLog"
	^false
			! !

!TestCase methodsFor: 'running' stamp: ''!
logFailure: aString
	self isLogging ifTrue: [
		self failureLog 
			cr; 
			nextPutAll: aString; 
			flush]
			! !

!TestCase methodsFor: 'running' stamp: 'bp 11/15/2004 18:17'!
openDebuggerOnFailingTestMethod
	"SUnit has halted one step in front of the failing test method. Step over the 'self halt' and 
	 send into 'self perform: testSelector' to see the failure from the beginning"

	self
		halt;
		performTest! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:22'!
performTest

	self perform: testSelector asSymbol
			! !

!TestCase methodsFor: 'printing' stamp: 'kph 1/6/2007 04:55'!
printOn: aStream

	aStream
		nextPutAll: self class printString;
		nextPutAll: '>>#';
		nextPutAll: testSelector;
		nextPutAll: ' {';
		nextPutAll: ((self class organization categoryOfElement: testSelector) ifNil: [ ' ' ]);
		nextPutAll: '}'.
			! !

!TestCase methodsFor: 'categorization utilities' stamp: 'kph 12/21/2006 04:06'!
removeCategoryMark: aWord

	"removes a (tag) from the category of this test method, e.g. 'tests (long)' => 'tests' "

	| categoryReader newCategory |

	self class methodDict at: self selector ifAbsent: [ ^ self ].
	
	categoryReader := ReadStream on: self category.

	newCategory := (categoryReader upToAll: ('(',aWord,')')), categoryReader upToEnd.

	^self class organization classify: self selector under: newCategory; removeEmptyCategories.! !

!TestCase methodsFor: 'dependencies' stamp: ''!
removeDependentFromHierachy: anObject 
	"an empty method. for Composite compability with TestSuite"


			! !

!TestCase methodsFor: 'accessing' stamp: ''!
resources
	| allResources resourceQueue |
	allResources := Set new.
	resourceQueue := OrderedCollection new.
	resourceQueue addAll: self class resources.
	[resourceQueue isEmpty] whileFalse: [
		| next |
		next := resourceQueue removeFirst.
		allResources add: next.
		resourceQueue addAll: next resources].
	^allResources
			! !

!TestCase methodsFor: 'running' stamp: 'kph 11/1/2006 20:21'!
run
	| result |
	result := TestResult new.
	self runOn: result.
	^ result! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
runCase

	[self setUp.
	self performTest] ensure: [self tearDown]
			! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
runCaseAsFailure: aSemaphore
	[self setUp.
	self openDebuggerOnFailingTestMethod] ensure: [
		self tearDown.
		aSemaphore signal]! !

!TestCase methodsFor: 'running' stamp: 'kph 11/1/2006 20:20'!
runOn: aResult 
	aResult runCase: self! !

!TestCase methodsFor: 'accessing' stamp: ''!
selector
	^testSelector
			! !

!TestCase methodsFor: 'private' stamp: ''!
setTestSelector: aSymbol
	testSelector := aSymbol
			! !

!TestCase methodsFor: 'running' stamp: ''!
setUp
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock
	self assert: aBlock value
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock description: aString
	self assert: aBlock value description: aString
			! !

!TestCase methodsFor: 'extensions' stamp: 'md 8/2/2006 11:09'!
should: aBlock notTakeMoreThan: aDuration
    "Evaluate aBlock in a forked process and if it takes more than anInteger milliseconds
    to run we terminate the process and report a test failure.  It'' important to
    use the active process for the test failure so that the failure reporting works correctly
    in the context of the exception handlers."

    | evaluated evaluationProcess result delay testProcess |

    evaluated := false.
    delay := Delay forDuration: aDuration.
    testProcess := Processor activeProcess.
    "Create a new process to evaluate aBlock"
    evaluationProcess := [
        result := aBlock value.
        evaluated := true.
        delay unschedule.
        testProcess resume ] forkNamed: 'Process to evaluate should: notTakeMoreThanMilliseconds:'.

    "Wait the milliseconds they asked me to"
    delay wait.
    "After this point either aBlock was evaluated or not..."
    evaluated ifFalse: [
        evaluationProcess terminate.
        self assert: false description: ('Block evaluation took more than the expected <1p>' expandMacrosWith: aDuration)].
   
    ^result! !

!TestCase methodsFor: 'extensions' stamp: 'md 8/2/2006 11:08'!
should: aBlock notTakeMoreThanMilliseconds: anInteger
    "For compatibility with other Smalltalks"

   self should: aBlock notTakeMoreThan: (Duration milliSeconds: anInteger).! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock raise: anExceptionalEvent 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent)
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock raise: anExceptionalEvent description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent)
		description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:32'!
should: aBlock raise: anExceptionalEvent whoseDescriptionDoesNotInclude: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: subString)
		description: aString
! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:24'!
should: aBlock raise: anExceptionalEvent whoseDescriptionIncludes: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: subString)
		description: aString
! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/20/2006 23:52'!
should: aBlock raise: anException withExceptionDo: anotherBlock 

	^self assert: (self executeShould: aBlock inScopeOf: anException withExceptionDo: anotherBlock)! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/20/2006 21:29'!
shouldFix: aBlock 

	^self should: aBlock raise: Exception! !

!TestCase methodsFor: 'testing' stamp: 'JF 7/30/2003 13:39'!
shouldPass
	"Unless the selector is in the list we get from #expectedFailures, we expect it to pass"
	^ (self expectedFailures includes: testSelector) not! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock
	self deny: aBlock value
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock description: aString
	self deny: aBlock value description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock raise: anExceptionalEvent 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent) not
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock raise: anExceptionalEvent description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent) not 		description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:34'!
shouldnt: aBlock raise: anExceptionalEvent whoseDescriptionDoesNotInclude: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: subString) not
		description: aString
! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:34'!
shouldnt: aBlock raise: anExceptionalEvent whoseDescriptionIncludes: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: subString) not
		description: aString
! !

!TestCase methodsFor: 'accessing' stamp: 'md 2/22/2006 14:26'!
signalFailure: aString
	TestResult failure signal: aString! !

!TestCase methodsFor: 'accessing' stamp: 'kph 12/19/2006 05:08'!
suite: aSymbol

"used to flag a test as being of a non standard test suite"! !

!TestCase methodsFor: 'running' stamp: ''!
tearDown
			! !

!TestCase methodsFor: 'accessing' stamp: 'kph 12/19/2006 05:13'!
testSuite: aSymbol

"used to flag a test as being of a non standard test suite"! !

TestCase subclass: #TestCaseVersioned
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!TestCaseVersioned commentStamp: 'kph 12/19/2006 06:01' prior: 0!
Provides flags for tests that are specific to a particular platform.

use:

self flag: #MacSpecificTest
self flag: #WindowsSpecificTes

When in 3.9, I want to be able to see, standard tests, with 

tests that will not work are 3.8 and earlier only,
Squeak3.7Earlier Squeak3.8Earlier Squeak3.10Later Squeak3.11Later

tests that will work are any earlier version and later   '
3.7+ 3.8+ 3.9+ 3.9only 3.9- 3.10- 
 !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/19/2006 05:42'!
allThePlatforms

^ #('include#WindowsSpecificTest' 'include#UnixSpecificTest' 'include#MacSpecificTest' 'include#RiscOsSpecificTest')! !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/19/2006 05:40'!
nonMacOsTests

^ #( #allThePlatforms 'exclude#MacSpecificTest' )! !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/19/2006 05:40'!
nonRiscOsTests

^ #( #allThePlatforms 'exclude#RiskOsSpecificTest' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:09'!
nonSqueak310Tests

^ #( #squeak39AndEarlier #squeak311AndLater )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:47'!
nonSqueak310VmTests

^ #( #squeak39AndEarlier #squeak311AndLater 'exclude@^*VM*')! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:44'!
nonSqueak36Tests

^ #( #squeak35AndEarlier #squeak37AndLater )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:59'!
nonSqueak36VmTests

^ #( #nonSqueak36Tests 'exclude@*^test vm*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:10'!
nonSqueak37Tests

^ #( #squeak36AndEarlier #squeak38AndLater )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:59'!
nonSqueak37VmTests

^ #( #nonSqueak37Tests 'exclude@*^test vm*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:23'!
nonSqueak38Tests

^ #( #squeak37AndEarlier #squeak39AndLater )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:59'!
nonSqueak38VmTests

^ #( #nonSqueak38Tests 'exclude@*^test vm*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:40'!
nonSqueak39Tests

^ #( #squeak38AndEarlier #squeak310AndLater )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:59'!
nonSqueak39VmTests

^ #( #nonSqueak39Tests 'exclude@*^test vm*' )! !

!TestCaseVersioned class methodsFor: '<3.9' stamp: 'kph 12/19/2006 06:06'!
nonSqueak3p8Tests

^ #( #squeak3p7AndEarlier #squeak3p9AndLater )! !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/19/2006 05:41'!
nonUnixTests

^ #( #allThePlatforms 'exclude#LinuxSpecificTest' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:40'!
nonVmSqueak39Tests

^ #( #squeak38AndEarlier #squeak310AndLater )! !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/19/2006 05:40'!
nonWin32Tests

^ #( #allThePlatforms 'exclude#WindowsSpecificTest' )! !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/19/2006 05:42'!
notThisPlatformFilters

	^Array with: ('non', self whatPlatformIsThis, 'Tests') asLegalSelector! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:09'!
notThisVersionFilters

	^Array with: ('non', self version, 'Tests') asLegalSelector! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:45'!
notThisVmVersionFilters

	^Array with: ('non', self vmVersion, 'VmTests') asLegalSelector! !

!TestCaseVersioned class methodsFor: 'published suites' stamp: 'kph 12/19/2006 06:45'!
publishedFilters
	^ super publishedFilters, self notThisPlatformFilters, self notThisVersionFilters, self notThisVmVersionFilters! !

!TestCaseVersioned class methodsFor: 'published suites' stamp: 'kph 12/19/2006 05:54'!
publishedSuites
	^ super publishedSuites ", (self in: self class selectorsMatching: 'squeak*AndEarlier') asArray"! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:26'!
squeak310AndEarlier

"method categorised with 'v38-*only', and 'v39*only'"

^ #( #squeak39AndEarlierBase  'include@*v3.10*'  )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:28'!
squeak310AndEarlierBase

"categorisation for squeak versions. e.g: 'v310- only' "

^ #( #squeak39AndEarlierBase  'include@*v3.10*earlier*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:37'!
squeak310AndLater

^ #( #squeak311AndLaterBase 'include@*v3.10*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:35'!
squeak310AndLaterBase

^ #( #squeak311AndLaterBase 'include@*v3.10*later' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:35'!
squeak311AndLaterBase

^ #( #squeak312AndLaterBase 'include@*v3.11*later*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:25'!
squeak37AndEarlier

"method categorised with 'v37-*only', and 'v38*only'"

^ #( #squeak36AndEarlierBase 'include@*v3.7*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:31'!
squeak37AndEarlierBase

"categorisation for squeak versions. e.g: 'v37- only' "

^ #( #squeak36AndEarlierBase 'include@*v3.7*earlier*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:36'!
squeak37AndLater

^ #( #squeak38AndLaterBase 'include@*v3.7*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:36'!
squeak37AndLaterBase

^ #( #squeak38AndLaterBase 'include@*v3.7*later*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:25'!
squeak38AndEarlier

"method categorised with 'v37-*only', and 'v38*only'"

^ #( #squeak37AndEarlierBase  'include@*v3.8*'  )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:30'!
squeak38AndEarlierBase

"categorisation for squeak versions. e.g: 'v38- only' "

^ #( #squeak37AndEarlierBase  'include@*v3.8*earlier*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:37'!
squeak38AndLater

^ #( #squeak39AndLaterBase 'include@*v3.8*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:36'!
squeak38AndLaterBase

^ #( #squeak39AndLaterBase 'include@*v3.8*later' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:25'!
squeak39AndEarlier

"method categorised with 'v38-*only', and 'v39*only'"

^ #( #squeak38AndEarlierBase  'include@*v3.9*'  )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:30'!
squeak39AndEarlierBase

self tag: #todo.
"categorisation for squeak versions. e.g: 'v39- only' "

^ #( #squeak38AndEarlierBase 'include@*v3.9*earlier*')! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:37'!
squeak39AndLater

^ #( #squeak310AndLaterBase 'include@*v3.9*' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 06:35'!
squeak39AndLaterBase

^ #( #squeak310AndLaterBase 'include@*v3.9*later' )! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 05:48'!
version

	^SystemVersion current majorMinorVersion! !

!TestCaseVersioned class methodsFor: 'version filters' stamp: 'kph 12/19/2006 05:48'!
vmVersion

	^SmalltalkImage current vmVersion upTo: $ .! !

!TestCaseVersioned class methodsFor: 'platform filters' stamp: 'kph 12/18/2006 01:51'!
whatPlatformIsThis

^ SmalltalkImage current platformName capitalized! !

TestCase subclass: #TestCaseVersionedTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

Object subclass: #TestResource
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

TestResource class
	instanceVariableNames: 'current'!

TestResource class
	instanceVariableNames: 'current'!

TestResource subclass: #ClassClonerTestResource
	instanceVariableNames: 'clones'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!ClassClonerTestResource commentStamp: 'kph 12/20/2006 20:01' prior: 0!
To enable testing of class-side behaviour without disturbing the class, or its superclasses which are singletons in use.

This TestResource provides a clone of an existing class on demand. Clones are created to behave in the same manner as the original class except that class vars are local copies, and its methods have been recompiled to reference them.

usage: (in fixture setup)

"obtain the clone"
clonedClass := ClassClonerTestResource current cloneOf: DateAndTime.
"the clone needs to be explicitly reset to a known state as needed before each test."
clonedClass initialize.!

!ClassClonerTestResource methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 19:49'!
cloneOf: origClass

	^ clones at: origClass ifAbsentPut: [ self makeCloneOf: origClass ]! !

!ClassClonerTestResource methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 19:47'!
makeCloneOf: origClass

	| clone |

	"copy the class"
	clone := origClass copy.

	origClass classPool keysAndValuesDo: [ :k :v | 
		 clone classPool at: k deepCopy put: v deepCopy.
	].
 
 	clone compileAll.
 
	^clone! !

!ClassClonerTestResource methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 19:47'!
setUp

clones := IdentityDictionary new.! !

!ClassClonerTestResource methodsFor: 'as yet unclassified' stamp: 'kph 12/20/2006 19:47'!
tearDown

clones := nil.! !

TestResource subclass: #SimpleTestResource
	instanceVariableNames: 'runningState hasRun hasSetup hasRanOnce'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SimpleTestResource methodsFor: 'testing' stamp: ''!
hasRun
	^hasRun
			! !

!SimpleTestResource methodsFor: 'testing' stamp: ''!
hasSetup
	^hasSetup
			! !

!SimpleTestResource methodsFor: 'testing' stamp: ''!
isAvailable
	
	^self runningState == self startedStateSymbol
			! !

!SimpleTestResource methodsFor: 'accessing' stamp: ''!
runningState

	^runningState
			! !

!SimpleTestResource methodsFor: 'accessing' stamp: ''!
runningState: aSymbol

	runningState := aSymbol
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
setRun
	hasRun := true
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
setUp
	
	self runningState: self startedStateSymbol.
	hasSetup := true
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
startedStateSymbol

	^#started
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
stoppedStateSymbol

	^#stopped
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
tearDown

	self runningState: self stoppedStateSymbol
			! !

!TestResource class methodsFor: 'accessing' stamp: ''!
current

	current isNil
		ifTrue: [current := self new].

	^current
			! !

!TestResource class methodsFor: 'accessing' stamp: ''!
current: aTestResource

	current := aTestResource
			! !

!TestResource class methodsFor: 'testing' stamp: 'md 2/22/2006 14:21'!
isAbstract
	"Override to true if a TestResource subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #TestResource
			! !

!TestResource class methodsFor: 'testing' stamp: ''!
isAvailable
	^self current notNil and: [self current isAvailable]
			! !

!TestResource class methodsFor: 'testing' stamp: ''!
isUnavailable

	^self isAvailable not
			! !

!TestResource class methodsFor: 'creation' stamp: ''!
reset

	current notNil ifTrue: [
		[current tearDown] ensure: [
			current := nil]]
			! !

!TestResource class methodsFor: 'accessing' stamp: ''!
resources
	^#()
			! !

!TestResource class methodsFor: 'creation' stamp: ''!
signalInitializationError
	^TestResult signalErrorWith: 'Resource ' , self name , ' could not be initialized'
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
description

	description isNil
		ifTrue: [^''].

	^description
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
description: aString

	description := aString
			! !

!TestResource methodsFor: 'initializing' stamp: ''!
initialize
	self setUp

			! !

!TestResource methodsFor: 'testing' stamp: ''!
isAvailable
	"override to provide information on the
	readiness of the resource"
	
	^true
			! !

!TestResource methodsFor: 'testing' stamp: ''!
isUnavailable
	"override to provide information on the
	readiness of the resource"
	
	^self isAvailable not
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
name

	name isNil
		ifTrue: [^self printString].

	^name
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
name: aString

	name := aString
			! !

!TestResource methodsFor: 'printing' stamp: ''!
printOn: aStream

	aStream nextPutAll: self class printString
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
resources
	^self class resources
			! !

!TestResource methodsFor: 'running' stamp: ''!
setUp
	"Does nothing. Subclasses should override this
	to initialize their resource"
			! !

!TestResource methodsFor: 'running' stamp: ''!
signalInitializationError
	^self class signalInitializationError
			! !

!TestResource methodsFor: 'running' stamp: ''!
tearDown
	"Does nothing. Subclasses should override this
	to tear down their resource"
			! !

Object subclass: #TestResult
	instanceVariableNames: 'failures errors passed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestResult commentStamp: '<historical>' prior: 0!
This is a Collecting Parameter for the running of a bunch of tests. TestResult is an interesting object to subclass or substitute. #runCase: is the external protocol you need to reproduce. Kent has seen TestResults that recorded coverage information and that sent email when they were done.!

!TestResult class methodsFor: 'exceptions' stamp: ''!
error
	^self exError
			! !

!TestResult class methodsFor: 'exceptions' stamp: 'md 2/22/2006 14:17'!
exError
	^Error
			! !

!TestResult class methodsFor: 'exceptions' stamp: ''!
failure
	^TestFailure
			! !

!TestResult class methodsFor: 'exceptions' stamp: ''!
resumableFailure
	^ResumableTestFailure
			! !

!TestResult class methodsFor: 'exceptions' stamp: 'md 2/22/2006 14:26'!
signalErrorWith: aString 
	self error signal: aString
			! !

!TestResult class methodsFor: 'exceptions' stamp: 'md 2/22/2006 14:26'!
signalFailureWith: aString 
	self failure signal: aString
			! !

!TestResult methodsFor: 'accessing' stamp: ''!
correctCount
	"depreciated - use #passedCount"

	^self passedCount
			! !

!TestResult methodsFor: 'accessing' stamp: ''!
defects
	^OrderedCollection new
		addAll: self errors;
		addAll: self failures; yourself
			! !

!TestResult methodsFor: 'accessing' stamp: ''!
errorCount

	^self errors size
			! !

!TestResult methodsFor: 'compatibility' stamp: 'JF 7/30/2003 16:09'!
errors
	^ self unexpectedErrors! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
expectedDefectCount
	^ self expectedDefects size! !

!TestResult methodsFor: 'accessing' stamp: 'md 11/25/2004 16:36'!
expectedDefects
	^ (errors, failures asOrderedCollection) select: [:each | each shouldPass not] ! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
expectedPassCount
	^ self expectedPasses size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
expectedPasses
	^ passed select: [:each | each shouldPass] ! !

!TestResult methodsFor: 'accessing' stamp: 'kph 11/1/2006 20:42'!
fail: a dueTo: b! !

!TestResult methodsFor: 'accessing' stamp: ''!
failureCount

	^self failures size
			! !

!TestResult methodsFor: 'compatibility' stamp: 'md 11/25/2004 16:23'!
failures
	^ self unexpectedFailures, self unexpectedPasses ! !

!TestResult methodsFor: 'testing' stamp: ''!
hasErrors

	^self errors size > 0
			! !

!TestResult methodsFor: 'testing' stamp: ''!
hasFailures

	^self failures size > 0
			! !

!TestResult methodsFor: 'testing' stamp: 'JF 7/30/2003 14:04'!
hasPassed
	^self runCount = (self passedCount + self expectedDefectCount)! !

!TestResult methodsFor: 'initialize-release' stamp: 'stephaneducasse 2/3/2006 22:41'!
initialize
	passed := OrderedCollection new.
	failures := Set new.
	errors := OrderedCollection new.! !

!TestResult methodsFor: 'testing' stamp: ''!
isError: aTestCase

	^self errors includes: aTestCase
			! !

!TestResult methodsFor: 'testing' stamp: ''!
isFailure: aTestCase
	^self failures includes: aTestCase
			! !

!TestResult methodsFor: 'testing' stamp: ''!
isPassed: aTestCase

	^self passed includes: aTestCase
			! !

!TestResult methodsFor: 'accessing' stamp: 'kph 11/1/2006 20:41'!
pass: a! !

!TestResult methodsFor: 'compatibility' stamp: 'JF 7/30/2003 16:08'!
passed
	^ self expectedPasses, self expectedDefects! !

!TestResult methodsFor: 'accessing' stamp: ''!
passedCount

	^self passed size
			! !

!TestResult methodsFor: 'printing' stamp: 'JF 7/30/2003 16:15'!
printOn: aStream
	aStream
		nextPutAll: self runCount printString;
		nextPutAll: ' run, ';
		nextPutAll: self expectedPassCount printString;
		nextPutAll: ' passes, ';
		nextPutAll: self expectedDefectCount printString;
		nextPutAll:' expected failures, ';
		nextPutAll: self unexpectedFailureCount printString;
		nextPutAll: ' failures, ';
		nextPutAll: self unexpectedErrorCount printString;
		nextPutAll:' errors, ';
		nextPutAll: self unexpectedPassCount printString;
		nextPutAll:' unexpected passes'.! !

!TestResult methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
runCase: aTestCase
	| testCasePassed |
	testCasePassed := true.
	[[aTestCase runCase] 
			on: self class failure
			do: 
				[:signal | 
				failures add: aTestCase.
				testCasePassed := false.
				signal return: false]]
					on: self class error
					do:
						[:signal |
						errors add: aTestCase.
						testCasePassed := false.
						signal return: false].
	testCasePassed ifTrue: [passed add: aTestCase]! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:07'!
runCount
	^ passed size + failures size + errors size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:06'!
tests
	^(OrderedCollection new: self runCount)
		addAll: passed;
		addAll: failures;
		addAll: errors;
		yourself! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
unexpectedErrorCount
	^ self unexpectedErrors size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
unexpectedErrors
	^ errors select: [:each | each shouldPass] ! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
unexpectedFailureCount
	^ self unexpectedFailures size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
unexpectedFailures
	^ failures select: [:each | each shouldPass] ! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
unexpectedPassCount
	^ self unexpectedPasses size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
unexpectedPasses
	^ passed select: [:each | each shouldPass not] ! !

TestResult subclass: #TestResultTimed
	instanceVariableNames: 'timings usesNetwork'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!TestResultTimed methodsFor: 'as yet unclassified' stamp: 'kph 1/6/2007 03:17'!
findLastInstanceFrom: aClassInstance 

	"finds the last instanciated instance of the same class as given"
	
	| inst next |
	
	next := aClassInstance.
	[next == nil] whileFalse: [ 
		inst := next. 
		next := inst nextInstance
	].

	^inst.
	 ! !

!TestResultTimed methodsFor: 'as yet unclassified' stamp: 'kph 1/6/2007 16:48'!
initialize
	 
	super initialize.
	usesNetwork := Dictionary new.
	timings := Dictionary new.! !

!TestResultTimed methodsFor: 'as yet unclassified' stamp: 'kph 1/6/2007 16:53'!
runCase: aTestCase
	
	| netUsed statsBefore |
 
	statsBefore := Socket statsOpened.

	self timings at: aTestCase put: ([ super runCase: aTestCase ] timeToRun).

	netUsed :=  statsBefore ~= Socket statsOpened.
		 
	self usesNetwork at: aTestCase put: netUsed.
	
 ! !

!TestResultTimed methodsFor: 'as yet unclassified' stamp: 'kph 1/6/2007 16:48'!
timings

	^ timings ! !

!TestResultTimed methodsFor: 'as yet unclassified' stamp: 'kph 1/6/2007 16:48'!
usesNetwork

	^ usesNetwork! !

Object subclass: #TestSuite
	instanceVariableNames: 'tests resources name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestSuite commentStamp: '<historical>' prior: 0!
This is a Composite of Tests, either TestCases or other TestSuites. The common protocol is #run: aTestResult and the dependencies protocol!

!TestSuite class methodsFor: 'instance creation' stamp: 'kph 12/19/2006 05:21'!
classes: classes suites: suites filters: filters select: selectOrRemove
		 
	 ^self new fromClasses: classes suites: suites filters: filters select: selectOrRemove
	
! !

!TestSuite class methodsFor: 'instance creation' stamp: ''!
named: aString

	^self new
		name: aString;
		yourself
			! !

!TestSuite methodsFor: 'accessing' stamp: 'kph 11/1/2006 20:24'!
add: aTest 
	self tests add: aTest! !

!TestSuite methodsFor: 'dependencies' stamp: 'md 2/22/2006 14:24'!
addDependentToHierachy: anObject
	self addDependent: anObject.
	self tests do: [ :each | each addDependentToHierachy: anObject]
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
addTest: aTest
	self tests add: aTest
			! !

!TestSuite methodsFor: 'accessing' stamp: 'kph 12/16/2006 05:20'!
addTests: aCollection 
	self tests addAll: aCollection		! !

!TestSuite methodsFor: 'accessing' stamp: ''!
defaultResources
	^self tests 
		inject: Set new
		into: [:coll :testCase | 
			coll
				addAll: testCase resources;
				yourself]
			! !

!TestSuite methodsFor: 'filtering' stamp: 'kph 12/19/2006 05:30'!
fromClasses: classes suites: suites filters: filters select: selectOrRemove
	
	 | theClasses filterAction suiteResults filterResults |

	theClasses := classes reject: [ :class | class isAbstract ].
	
	filterAction := selectOrRemove ifTrue: [ #intersection: ] ifFalse: [ #difference: ].

	theClasses do: [ :class |

		suiteResults := self class new.  				
		suites do: [ :spec | class suite: spec onTo: suiteResults ].
		filterResults := self class new.
		filters do: [ :spec |  class suite: spec onTo: filterResults ].
		
		self addTests: (suiteResults tests perform: filterAction with: filterResults tests).
	].

	^self
! !

!TestSuite methodsFor: 'accessing' stamp: ''!
name

	^name
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
name: aString

	name := aString
			! !

!TestSuite methodsFor: 'filtering' stamp: 'kph 12/19/2006 04:47'!
removeAllFoundIn: aCollection

	tests removeAllFoundIn: aCollection! !

!TestSuite methodsFor: 'accessing' stamp: 'kph 12/16/2006 07:21'!
removeAllTests 

 tests := nil.! !

!TestSuite methodsFor: 'dependencies' stamp: 'md 2/22/2006 14:24'!
removeDependentFromHierachy: anObject
	self removeDependent: anObject.
	self tests do: [ :each | each removeDependentFromHierachy: anObject]
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
resources
	resources isNil ifTrue: [resources := self defaultResources].
	^resources
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
resources: anObject
	resources := anObject
			! !

!TestSuite methodsFor: 'running' stamp: 'kph 11/1/2006 20:21'!
run
	| result |
	result := TestResult new.
	self resources
		do: [:res | res isAvailable
				ifFalse: [^ res signalInitializationError]].
	[self runOn: result]
		ensure: [self resources
				do: [:each | each reset]].
	^ result! !

!TestSuite methodsFor: 'running' stamp: 'kph 11/1/2006 20:21'!
runOn: aResult 
	self tests
		do: [:each | 
			self changed: each.
			each runOn: aResult]! !

!TestSuite methodsFor: 'accessing' stamp: 'kph 12/16/2006 05:19'!
tests
	tests isNil ifTrue: [tests := Set new].
	^tests
			! !
ClassClonerTestResourceTest initialize!
